@@ -53,6 +53,7 @@
 #' # Briefly define argument values that will be plugged in later on in the functions.
 #' # We only use two trials as the function takes a long time to run.
 #'
+#' data(example_data)
 #' cs1 <- paste0("CSP", 1:2)
 #' cs2 <- paste0("CSM", 1:2)
 #' subj <- "id"
@@ -170,6 +171,8 @@ rm_banova_mf <- function(cs1,
     p.value = NA,
     effect.size = NA,
     effect.size.ma = NA,
+    effect.size.lci = NA,
+    effect.size.hci = NA,
     effect.size.ma.lci = NA,
     effect.size.ma.hci = NA,
     estimate = bfum,
